/* -*- C++ -*-
 *
 * This file is a part of LEMON, a generic C++ optimization library
 *
 * Copyright (C) 2003-2006
 * Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
 * (Egervary Research Group on Combinatorial Optimization, EGRES).
 *
 * Permission to use, modify and distribute this software is granted
 * provided that this copyright notice appears in all copies. For
 * precise terms see the accompanying LICENSE file.
 *
 * This software is provided "AS IS" with no warranty of any kind,
 * express or implied, and with no claim as to its suitability for any
 * purpose.
 *
 */

#include "gui_writer.h"
#include "xml.h"
#include "mapstorage.h"
#include <lemon/dim2.h>
#include <vector>

std::string GuiWriter::header()
{
  return "@gui";
}

void GuiWriter::write(std::ostream& os)
{
  XmlIo x(os);
  std::map<int, XY > m;
  for (EdgeIt e(mapstorage->graph); e != INVALID; ++e)
  {
    int edgeid = (int)(*(mapstorage->edgemap_storage["label"]))[e];
    m[edgeid] = mapstorage->arrow_pos[e];
  }
  x("arrow_pos", m);

  std::map<int, std::string> nm;
  for(int i=0;i<NODE_PROPERTY_NUM;i++)
    {
      nm[i]=mapstorage->active_nodemaps[i];
    }
  x("active_nodemaps", nm);

  std::map<int, std::string> em;
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
    {
      em[i]=mapstorage->active_edgemaps[i];
    }
  x("active_edgemaps", em);
}

GuiWriter::GuiWriter(LemonWriter& writer, MapStorage* ms) : Parent(writer), mapstorage(ms)
{
}
